@@ -1,5 +1,5 @@
 #[macro_export] macro_rules!
 hide {
-    ($a:expr; $($arg:tt)*) => ($($arg)*);
+    (- $a:expr; $($arg:tt)*) => ($($arg)*);
     ($($arg:tt)*) => ($($arg)*);
 }
