@@ -20,4 +20,8 @@ pub type Maybe<T> = Option<T>;
 
 pub type text = &'static str;
 use std::io::*;
-fn ERROR<T>(a: &'static str) -> std::io::Result<T> { Err(Error::new(ErrorKind::Other, a)) }
+pub fn ERROR<T>(a: &'static str) -> std::io::Result<T> { Err(Error::new(ErrorKind::Other, a)) }
+
+pub fn print_type_of<T>(_: &T) {
+    println!("{}", std::any::type_name::<T>())
+}
